@@ -9,7 +9,7 @@ from geojson_pydantic.geometries import Geometry
 from geojson_pydantic.types import BBox
 
 Props = TypeVar("Props", bound=Dict)
-Geom = TypeVar("Geom", bound=Geometry)
+Geom = TypeVar("Geom", bound=Optional[Geometry])
 
 
 class Feature(GenericModel, Generic[Geom, Props]):
